@@ -1163,14 +1163,14 @@ g_vfs_dns_sd_resolver_resolve (GVfsDnsSdResolver  *resolver,
       g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_FAILED,
                                _("Error initializing Avahi resolver"));
       g_object_unref (task);
-      goto out;
+      return;
     }
 
   if (resolver->is_resolved)
     {
       g_task_return_boolean (task, TRUE);
       g_object_unref (task);
-      goto out;
+      return;
     }
 
   ensure_avahi_resolver (resolver);
@@ -1187,9 +1187,6 @@ g_vfs_dns_sd_resolver_resolve (GVfsDnsSdResolver  *resolver,
                     "changed",
                     (GCallback) service_resolver_changed,
                     task);
-
- out:
-  ;
 }
 
 
